Changelog
=========

1.0.6 (2020-07-09)
------------------

 - Add option for public/canonical site url [alecpm]
 - Python 3 compatibility [alecpm]

1.0.5 (2019-11-19)
------------------

 - Documentation updates [sallyk]


1.0.4 (2019-11-15)
------------------

 - Fix the save and cancel buttons in siteimprove controlpanel [batlock666]
 - Update rolemap to grant Editor and Reviewer role to siteimprove functionality by default [witekdev]
 - Update PYPI classifier. Tested with Plone 5.2


1.0.3 (2018-11-08)
------------------

 - Documentation updates [sallyk]


1.0.2 (2018-09-19)
------------------

- Documentation updates [sallyk]


1.0.1 (2018-08-14)
------------------

- Use canonical url for input, domain and recheck functions [witekdev]
- Call input function on add/edit views, domain on all others [witekdev]
- Trigger recheck when object saved and publically visible or on any workflow transition [witekdev]


0.1a2 (2018-05-09)
------------------

- Call `input` method on visible page loads.
  [alecpm]


0.1a1 (2018-05-09)
------------------

- Initial release.
  [witekdev]
